
% Syntax:
% aR = ArrayRec(M,var,theta,sigma);
%
% This MATLAB function simulates the ARRAY OF RECEIVERS.
% It obtains the SAMPLE COVARIANCE MATRIX as a function of the 
% number of receivers (M), the direction or angle of arrival 
% (theta) and the received power (sigma), adding an error 
% (white Gaussian noise) that simulates the finite sample 
% support, imperfect array calibration, etc.
% It uses the function 'aassumed.m'.
%
% Input:
% M     - number of receivers in the array
% var   - variance of the white Gaussian error produced in the 
%         array
% theta - row vector containing the DOA of the different 
%         sources (degrees -90 to +90)
% sigma - row vector containing the ISP of the different 
%         sources (dB)
%
% Output:
% aR    - sample covariance matrix
%
%
% EXAMPLE1:
%
% M = 10;
% var = 0.06;
% theta = [-35 -15 0 10 40];
% sigma = [30 60 40 35 10];


function aR = ArrayRec(M,var,theta,sigma);

aR = 0;

% Number of signals arriving to the receiver:
n = max(size(theta));

% Signal directions in degrees (0 to +180):
thetad = theta + 90;

% Signal directions in radians:
thetar = thetad.*pi./180;

% Signal powers (linear):
sigmal = 10.^(sigma./10);

% TRUE Steering vectors:
a = ones(n,M);
for i = 1:n,
    for rec = 1:M,
        a(i,rec) = exp(-j*(rec-1)*pi*cos(thetar(i)));
    end
end

a = a.';

% We define the true steering vector ERROR 
%   epsilon0 = min_alpha norm( a*exp(j*alpha) - aa )^2 , 
% where a is the true steering vector, and aa is the assumed 
% one.

% ASSUMED Steering vectors:
aa = aassumed(var,a);

% ASSUMED Steering vectors (conjugate transpose):
aact = aa';

% Noise covariance matrix:
Q = eye(M);

% Theoretical covariance matrix of the array output vector 
% (assumed one):
aR = Q;
for i = 1:n,
    aR = aR + sigmal(i)*aa(:,i)*aact(i,:);
end

% -------------------------------------------------------------
