
% Syntax:
% [theta,ISPdB] = DCRCB_ISPdB(M,aR);
%
% This MATLAB function simulates a Doubly Constrained Robust 
% Capon Beamformer. 
% It obtains the Incident Signal Power as a function of the 
% angle of arrival, theta.
% It uses the function 'lambda329.m'.
%
% Input:
% M     - number of receivers in the array
% aR    - sample covariance matrix
%
% Output:
% theta - angle of arrival, theta (degrees -90 to +90)
% ISPdB - Incident Signal Power (dB)
%
%
% EXAMPLE1:
%
% M = 10;

function [theta,ISPdB] = DCRCB_ISPdB(M,aR);

theta = 0;
ISPdB = 0;

% Step 1) Compute the eigendecomposition of R (or, in practice,
% of ^R).

[U,Gamma,V] = svd(aR);
Uct = U';

% Step 2) If (3.28) is satisfied, solve (3.29) for ^landa, 
% e.g., by a Newton's method, using the knowledge that the 
% solution is unique and it is lower bounded by -1/gamma1 and 
% upper bounded by (3.30), and then continue to Step 3; 
% otherwise, compute ^sigma0_2 = gamma1/M and stop.

% Let u1 denote the first eigenvector in U:
u1 = U(:,1);

epsilon = 1.0;
cond = M - epsilon/2;
rho = M/(cond^2);

% A vector containing the main diagonal of inv(Gamma):
iGamma = 1./diag(Gamma);

% Lower bound on lambda:
lblambda = -iGamma(1);
% Upper bound on lambda:
ublambda = ( iGamma(M) - ((M*rho)^(1/2))*iGamma(1) )/...
    ( ((M*rho)^(1/2)) - 1 );


i = 1;
s_a = zeros(1,241);
ISP = zeros(1,241);

for theta = -60+90:1/2:60+90,
   
    theta = theta*pi/180;
    
    a = ones(M,1);
    for rec = 1:M,
        a(rec) = exp(-j*(rec-1)*pi*cos(theta));
    end
    
    act = a';
    
    % angle(x) returns the phase angles, in radians, of a 
    % matrix with complex elements:
    phi = angle(u1'*a);
    
    est_a = M^(1/2)*u1*exp(j*phi);
    
    R_a_times_a = real(act*est_a);

    z = Uct*a;

    % (3.28) == Re(a*est_a) < M - epsilon/2

    if R_a_times_a < cond
        [lambda] = lambda329(M,rho,z,iGamma,lblambda,ublambda);
    else
        lambda = 0;
        ISP(i) = Gamma(1,1)/M;
        % Continue to the next iteration:
        i = i + 1;
        continue
    end

    dmatrix = eye(M) + lambda*Gamma;
    idmatrix = diag(1./diag(dmatrix));
    idmatrix2 = idmatrix*idmatrix;
    
    ISP(i) = (1 / cond^2) * ((act*U*idmatrix*Gamma*z)^2) /...
        ( act*U*idmatrix2*Gamma*z );
    i = i + 1;
    
end
    
theta = -60:1/2:60;
ISPdB = 10*log10( real(ISP) );

% -------------------------------------------------------------
