
% Syntax:
% [DOA,ISPdB] = ISPdBvsDOA(M,var,theta,sigma);
%
% This MATLAB function obtains and plots the Incident Signal 
% Power (ISP) as a function of the Direction Of Arrival (DOA). 
% It uses the functions 'ArrayRec.m' and 'mmpolar.m'.
%
% Input:
% M     - number of receivers in the array
% var   - variance of the white Gaussian error produced in the 
%         array
% theta - row vector containing the DOA of the different 
%         sources (degrees -90 to +90)
% sigma - row vector containing the ISP of the different 
%         sources (dB)
%
% Output:
% DOA   - Direction Of Arrival (degrees -90 to +90)
% ISPdB - Incident Signal Power (dB)
%
%
% EXAMPLE1:
%
% M = 10;
% var = 0.06;
% theta = [-35 -15 0 10 40];
% sigma = [30 60 40 35 10];


function [DOA,ISPdB] = ISPdBvsDOA(M,var,theta,sigma);

DOA = 0;
ISPdB = 0;

aR = ArrayRec(M,var,theta,sigma);
% -------------------------------------------------------------

[theta1,ISPdB1] = DASB_ISPdB(M,aR);
[theta2,ISPdB2] = SCB_ISPdB(M,aR);
[theta3,ISPdB3] = RCB_ISPdB(M,aR);
[theta4,ISPdB4] = NCCB_ISPdB(M,aR);
[theta5,ISPdB5] = DCRCB_ISPdB(M,aR);

DOA = [theta1 ; theta2 ; theta3; theta4; theta5];
ISPdB = [ISPdB1 ; ISPdB2 ; ISPdB3; ISPdB4; ISPdB5];

% Plotting:

close all hidden

clf;
hold on;
box on;
xlabel('DOA degree');
ylabel('ISP [dB]');
grid;

% The real signals arriving to the array:
plot(theta,sigma,'ok');

plot(theta1,ISPdB1,'g');
plot(theta2,ISPdB2,'c');
plot(theta3,ISPdB3,'m');
plot(theta4,ISPdB4);
plot(theta5,ISPdB5,'r');

%h = legend('real values','DASB','SCB','RCB','NCCB','DCRCB');

thetapolar = theta.*pi./180;
thetapolar1 = theta1.*pi./180;
thetapolar2 = theta2.*pi./180;
thetapolar3 = theta3.*pi./180;
thetapolar4 = theta4.*pi./180;
thetapolar5 = theta5.*pi./180;

figure;

% The real signals arriving to the array:
mmpolar(thetapolar,sigma,'ok');
hold on;

mmpolar(thetapolar1,ISPdB1,'g');
mmpolar(thetapolar2,ISPdB2,'c');
mmpolar(thetapolar3,ISPdB3,'m');
mmpolar(thetapolar4,ISPdB4);
mmpolar(thetapolar5,ISPdB5,'r');

mmpolar('TTickDelta',15,'TLimit',[-pi/2 pi/2]);
view(90,-90);
ylabel('ISP [dB] vs. DOA degree');

k = legend('real values','DASB','SCB','RCB','NCCB','DCRCB');

% -------------------------------------------------------------
