
% Syntax:
% [theta,ISPdB] = NCCB_ISPdB(M,aR);
%
% This MATLAB function simulates a Norm Constrained Capon 
% Beamformer. It obtains the Incident Signal Power as a 
% function of the angle of arrival, theta.
% It uses the function 'lambda319.m'.
%
% Input:
% M     - number of receivers in the array
% aR    - sample covariance matrix
%
% Output:
% theta - angle of arrival, theta (degrees -90 to +90)
% ISPdB - Incident Signal Power (dB)
%
%
% EXAMPLE1:
%
% M = 10;

function [theta,ISPdB] = NCCB_PvsTheta(M,aR);

% Step 1) Compute the eigendecomposition of R (or, in practice,
% of ^R).

[U,Gamma,V] = svd(aR);

% Step 2) If (3.20) is satisfied, solve (3.19) for ^landa, 
% e.g., by a Newton's method, using the knowledge that the 
% solution is unique and it is lower bounded by 0 and upper 
% bounded by (3.21); otherwise, set ^landa = 0.

% (3.20)  ==  zeta < cond

beta = 6.0; 
% so that the peak widths of the NCCB and DCRCB are about the 
% same.

zeta = beta / M;

Uct = U';

dGamma = diag(Gamma);
R_1 = U*diag(1./dGamma)*Uct;
R_2 = R_1*R_1;

% (3.21)

% Lower bound on lambda:
lblambda = 0;
% Upper bound on lambda:
ublambda = ( dGamma(1) - ((M*zeta)^(1/2))*dGamma(M) )/...
    ( ((M*zeta)^(1/2)) - 1 );

i = 1;
ISP = zeros(1,241);

for theta = -60+90:1/2:60+90,
   
    theta = theta*pi/180;
    
    a = ones(M,1);
    for rec = 1:M,
        a(rec) = exp(-j*(rec-1)*pi*cos(theta));
    end
    
    act = a';
    cond = real( (act*R_2*a)/(act*R_1*a)^2 );
    
    z = Uct*a;

    if zeta < cond
        [lambda]=lambda319(M,zeta,z,dGamma,lblambda,ublambda);
    else
        lambda = 0;
    end
    
    dmatrix = Gamma + lambda*eye(M);
    idmatrix = diag(1./diag(dmatrix));
    w = U*idmatrix*z / (act*U*idmatrix*z);
    wct = w';
    
    % Incident Signal Power:
    ISP(i) = wct*aR*w;
    
    i = i + 1;
    
end

theta = -60:1/2:60;
ISPdB = 10*log10( real(ISP) );

% -------------------------------------------------------------
