
% Syntax:
% [theta,ISPdB] = RCB_ISPdB(M,aR);
%
% This MATLAB function simulates a Robust Capon Beamformer. 
% It obtains the Incident Signal Power as a function of the 
% angle of arrival, theta.
% It uses the function 'lambda310.m'.
%
% Input:
% M     - number of receivers in the array
% aR    - sample covariance matrix
%
% Output:
% theta - angle of arrival, theta (degrees -90 to +90)
% ISPdB - Incident Signal Power (dB)
%
%
% EXAMPLE1:
%
% M = 10;


function [theta,ISPdB] = RCB_ISPdB(M,aR);

theta = 0;
ISPdB = 0;

% Step 1) Compute the eigendecomposition of R (or more 
% practically of ^R).

[U,Gamma,V] = svd(aR);
Uct = U';

gamma = zeros(1,M);
gamma(1) = Gamma(1,1);
for i = 2:M,
    gamma(i) = Gamma(i,i);
end
gamma = gamma.';
% Example with M = 10:
%gamma = [Gamma(1,1) Gamma(2,2) Gamma(3,3) Gamma(4,4)...
%Gamma(5,5) Gamma(6,6) Gamma(7,7) Gamma(8,8) Gamma(9,9)...
%Gamma(10,10)].';

% Step 2) Solve equation (3.10) for landa, e.g., by a Newton's 
% method, using the knowledge that the solution is unique and 
% it belongs to the interval in (3.11).

epsilon = 1.0;

i = 1;
ISP = zeros(1,241);

for theta = -60+90:1/2:60+90,
   
    theta = theta*pi/180;
    
    a = ones(M,1);
    for rec = 1:M,
        a(rec) = exp(-j*(rec-1)*pi*cos(theta));
    end
    
    act = a';
    
    z = Uct*a; 
    
    % Lower bound on lambda:
    lblambda = ( norm(a) - sqrt(epsilon) )/...
        ( gamma(1)*sqrt(epsilon) );
    % Upper bound on lambda:
    ublambda = min([ ( ((1/epsilon)*sum((abs(z).^2)./gamma.^2))^(1/2) ) ( (norm(a)-sqrt(epsilon))/(gamma(M)*sqrt(epsilon)) ) ]);
    
    [lambda] = lambda310(epsilon,z,gamma,lblambda,ublambda);
    
    % Step 3)
    
    dmatrix = eye(M) + lambda*Gamma;
    idmatrix = diag(1./diag(dmatrix));
    
    a0 = a - U*idmatrix*Uct*a;
    
    % Step 4)
    
    longdmatrix = lambda^(-2)*eye(M) + 2*lambda^(-1)*Gamma +...
        Gamma^2;
    ilongdmatrix = diag(1./diag(longdmatrix));
    
    ISP(i) = 1 / ( act*U*Gamma*ilongdmatrix*Uct*a ) ;
    
    i = i + 1;
    
end
    
theta = -60:1/2:60;
ISPdB = 10*log10( real(ISP) );

% -------------------------------------------------------------
